@@ -16,22 +16,22 @@ import json
 from datetime import timedelta
 from typing import Any
 
-from robotlibcore import keyword  # type: ignore
+from robot.utils import DotDict  # type: ignore
 
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
-from ..utils import logger
+from ..utils import DownloadedFile, keyword, logger
 
 
 class Evaluation(LibraryComponent):
-    @keyword(name="Execute JavaScript", tags=["Setter", "Getter", "PageContent"])
+    @keyword(name="Execute JavaScript", tags=("Setter", "Getter", "PageContent"))
     def execute_javascript(self, function: str, selector: str = "") -> Any:
         """Executes given javascript on the page.
 
-        ``function`` <str> A valid javascript function or a javascript function body. For example
-        ``() => true`` and ``true`` will behave similarly. **Required**
+        ``function`` A valid javascript function or a javascript function body. For example
+        ``() => true`` and ``true`` will behave similarly.
 
-        ``selector`` <str> Selector to resolve and pass to the JavaScript function. This will be the first
+        ``selector`` Selector to resolve and pass to the JavaScript function. This will be the first
         argument the function receives. If given a selector a function is necessary, with an argument
         to capture the elementhandle. For example ``(element) => document.activeElement === element``
         See the `Finding elements` section for details about the selectors.
@@ -46,7 +46,7 @@ class Evaluation(LibraryComponent):
             if response.result:
                 return json.loads(response.result)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def highlight_elements(
         self,
         selector: str,
@@ -57,16 +57,16 @@ class Evaluation(LibraryComponent):
     ):
         """Adds a highlight to elements matched by the ``selector``. Provides a style adjustment.
 
-        ``selector`` <str> Selectors which shall be highlighted. **Required**
+        ``selector`` Selectors which shall be highlighted.
         See the `Finding elements` section for details about the selectors.
 
-        ``duration`` <str> Sets for how long the selector shall be highlighted. Defaults to ``5s`` => 5 seconds.
+        ``duration`` Sets for how long the selector shall be highlighted. Defaults to ``5s`` => 5 seconds.
 
-        ``width`` <str> Sets the width of the higlight border. Defaults to 2px.
+        ``width`` Sets the width of the higlight border. Defaults to 2px.
 
-        ``style`` < ``solid`` | ``dotted`` | ``double`` | ``dashed`` > Sets the style of the border. Defaults to dotted.
+        ``style`` Sets the style of the border. Defaults to dotted.
 
-        ``color`` <str> Sets the color of the border. Valid colors i.e. are:
+        ``color`` Sets the color of the border. Valid colors i.e. are:
         ``red``, ``blue``, ``yellow``, ``pink``, ``black``
         """
         with self.playwright.grpc_channel() as stub:
@@ -81,22 +81,28 @@ class Evaluation(LibraryComponent):
             )
             logger.info(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def add_style_tag(self, content: str):
         """Adds a <style type="text/css"> tag with the content.
 
-        ``content`` <str> Raw CSS content to be injected into frame. **Required**
+        ``content`` Raw CSS content to be injected into frame.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.AddStyleTag(Request().StyleTag(content=content))
             logger.info(response.log)
 
-    @keyword(tags=["Page Content"])
-    def download(self, url: str) -> str:
-        """
-        Download given url content and return downloaded file path
+    @keyword(tags=("Page Content",))
+    def download(self, url: str) -> DownloadedFile:
+        """Download given url content.
+
+        Keyword returns dictionary which contains downloaded file path
+        and suggested filename as keys (saveAs and suggestedFilename).
+        See `Wait For Download` for more details.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.Download(Request().Url(url=url))
-            logger.info(response.log)
-            return response.body
+        logger.info(response.log)
+        dot_dict = DotDict()
+        for key, value in json.loads(response.json).items():
+            dot_dict[key] = value
+        return dot_dict
